﻿-- **************************************************************************
-- * Titan Currency .lua - VERSION 5.4
-- **************************************************************************
-- * by Greenhorns @ Vek'Nilash
-- * This mod will display all the Currency you have on the curent toon
-- * in a tool tip.  It shows the curent Toons Gold amount on the Titan Panel
-- * bar.
-- *
-- **************************************************************************

-- ******************************** Constants *******************************
local TITAN_CURRENCY_ID = "Currency";
local TITAN_CURRENCY_COUNT_FORMAT = "%d";
local TITAN_CURRENCY_VERSION = "5.1";
local TITAN_CURRENCY_SPACERBAR = "--------------------";
local TITAN_CURRENCY_BLUE = {r=0.4,b=1,g=0.4};
local TITAN_CURRENCY_RED = {r=1,b=0,g=0};
local TITAN_CURRENCY_GREEN = {r=0,b=0,g=1};
-- ******************************** Variables *******************************
local CURRENCY_INITIALIZED = false;
local CURRENCY_VARIABLES_LOADED = false;
local CURRENCY_ENTERINGWORLD = false;
local CURRENCY_INDEX = "";
local CURRENCY_COLOR;
local CURRENCY_SESS_STATUS;
local CURRENCY_PERHOUR_STATUS;
local CURRENCY_STARTINGGOLD;
local CURRENCY_SESSIONSTART;
local REMEMBER_VIEWALL;
local REMEMBER_SORTBYNAME;
local REMEMBER_SHOWGPH;
local L = LibStub("AceLocale-3.0"):GetLocale("Titan", true)
local LB = LibStub("AceLocale-3.0"):GetLocale("Titan_Currency", true)
local TitanCurrency = LibStub("AceAddon-3.0"):NewAddon("TitanCurrency", "AceHook-3.0", "AceTimer-3.0")
local CurrencyTimer = nil;
local _G = getfenv(0);
-- ******************************** Functions *******************************

-- **************************************************************************
-- NAME : TitanPanelCurrencyButton_OnLoad()
-- DESC : Registers the add on upon it loading
-- **************************************************************************
function TitanPanelCurrencyButton_OnLoad(self)
     self.registry = { 
          id = TITAN_CURRENCY_ID,
          -- builtIn = nil,
          category = "Information",
          version = TITAN_CURRENCY_VERSION,
          menuText = LB["TITAN_CURRENCY_MENU_TEXT"], 
          tooltipTitle = LB["TITAN_CURRENCY_TOOLTIP"],
          tooltipTextFunction = "TitanPanelCurrencyButton_GetTooltipText",
          buttonTextFunction = "TitanPanelCurrencyButton_GetButtonText",
        controlVariables = {
			DisplayOnRightSide = true,
		},
        savedVariables = {
			DisplayOnRightSide = false,             
		},
     };

     self:RegisterEvent("PLAYER_ENTERING_WORLD");
     self:RegisterEvent("PLAYER_MONEY");
     self:RegisterEvent("VARIABLES_LOADED");
     self:RegisterEvent("UNIT_NAME_UPDATE");
     MoneyFrame_Update("TitanPanelCurrencyButton", TitanPanelCurrencyButton_FindGold());
     -- support for picking up money     
     
     if (not CurrencyArray) then 
          CurrencyArray={};
          CurrencyArray["VIEWALL"] = true
          CurrencyArray["DISPLAYGPH"] = true
     end
     
end

function TitanCurrency_OnEvent(self, event, ...)

     if (event == "VARIABLES_LOADED") then
          CURRENCY_VARIABLES_LOADED = true;
          if (CURRENCY_ENTERINGWORLD) then
               TitanPanelCurrencyButton_Initialize_Array(self);
          end
          return;
     end

     if ( event == "PLAYER_ENTERING_WORLD" ) then
          CURRENCY_ENTERINGWORLD = true;
          if (CURRENCY_VARIABLES_LOADED) then          		
               TitanPanelCurrencyButton_Initialize_Array(self);
          end
          return;
     end

     if (event == "PLAYER_MONEY") then
          if (CURRENCY_INITIALIZED) then
               MoneyFrame_Update("TitanPanelCurrencyButton", TitanPanelCurrencyButton_FindGold());
          end
          return;
     end
end
 
-- *******************************************************************************************
-- NAME: TitanPanelCurrencyButton_GetTooltipText()
-- DESC: Gets our tool-tip text, what appears when we hover over our item on the Titan bar.
-- *******************************************************************************************
function TitanPanelCurrencyButton_GetTooltipText()
   local display="";
   local tooltip="";
   local name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown;
   cCount = GetCurrencyListSize();
   for index=1, cCount do 
      name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown = GetCurrencyListInfo(index)
      if (count~=0) and not isUnused then
            if icon~=nil then
         display=name.."--".."\t"..count.." |T"..icon..":16|t"
            end
         -- trace(display)
         tooltip=strconcat(tooltip,display,"|r\n")
      end
      
      
      myindex=index
   end 
final_tooltip=tooltip
     return ""..final_tooltip;    
end


-- *******************************************************************************************
-- NAME: TitanPanelCurrencyButton_FindGold()
-- DESC: This routines determines which gold total the ui wants (server or player) then calls it and returns it
-- *******************************************************************************************
function TitanPanelCurrencyButton_FindGold()
     
    
    local ttlgold = 0;
    ttlgold = GetMoney("player");
    return ttlgold;
end


function TitanPanelCurrencyButton_Initialize_Array(self)

     if (not CurrencyArray["INITIALIZED"]) then
          CurrencyArray = {};
          CurrencyArray["INITIALIZED"] = true;
          CurrencyArray["VIEWALL"] = true;
          CurrencyArray["DISPLAYGPH"] = true;
          CurrencyArray["SORTBYNAME"] = true;
          CurrencyArray["VERSION2"] = true;
     end
	if  type(TitanCurrencSettings) == "nil" then 
        TitanCurrencSettings{}
    end	 
	if  type(TitanCurrencSettings.Sortbynothing) == "nil" then 
        TitanCurrencSettings.Sortbynothing=true
    end
	if type(TitanCurrencSettings.Sortbyalphaup) == "nil" then
		TitanCurrencSettings.Sortbyalphaup=false
	end
	if  type(TitanCurrencSettings.Sortbyalphadown) == "nil" then 
        TitanCurrencSettings.Sortbyalphadown=false
    end
	if type(TitanCurrencSettings.Sortbynumup) == "nil" then
		TitanCurrencSettings.Sortbyalphaup=false
	end
	if  type(TitanCurrencSettings.Sortbynumdown) == "nil" then 
        TitanCurrencSettings.Sortbyalphadown=false
    end
    --************************************** Options Panel.
     TitanCurrency.panel = CreateFrame( "Frame", "TitanCurrencyPanel", UIParent );
 -- Register in the Interface Addon Options GUI
 -- Set the name for the Category for the Options Panel
 
 
 TitanCurrency.panel.name = "Titan Currency";
 local title = TitanCurrency.panel:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetPoint("TOPLEFT", 16, -15)
	title:SetText("Titan Currency Options")
 -- Add the panel to the Interface Options
	InterfaceOptions_AddCategory(TitanCurrency.panel);
 	TitanCurrency.panel:SetScript("OnShow", function()
		Sortbynone:SetChecked(TitanCurrencSettings.Sortbynothing)
		SortbyAlphaAscending:SetChecked(TitanCurrencSettings.Sortbyalphaup)
		SortbyAlphaDescending:SetChecked(TitanCurrencSettings.Sortbyalphadown)
		SortbyNumAscending:SetChecked(TitanCurrencSettings.Sortbynumup)
		SortbyNumDescending:SetChecked(TitanCurrencSettings.sortbynumdown)
	end)

    

	
	--Sort by nothing
	
	    local btnSortbynone = CreateFrame("CheckButton", "Sortbynone", TitanCurrencyPanel, "OptionsBaseCheckButtonTemplate")
	btnSortbynone:SetPoint("TOPLEFT", 16, -75)
	btnSortbynone:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
	--		PlaySound("igMainMenuOptionCheckBoxOn")
			TitanCurrencSettings.Sortbynothing = true
			TitanCurrencSettings.Sortbyalphaup = false
			TitanCurrencSettings.Sortbyalphadown = false
			TitanCurrencSettings.Sortbynumup = false
			TitanCurrencSettings.sortbynumdown = false
		Sortbynone:SetChecked(TitanCurrencSettings.Sortbynothing)
		SortbyAlphaAscending:SetChecked(TitanCurrencSettings.Sortbyalphaup)
		SortbyAlphaDescending:SetChecked(TitanCurrencSettings.Sortbyalphadown)
		SortbyNumAscending:SetChecked(TitanCurrencSettings.Sortbynumup)
		SortbyNumDescending:SetChecked(TitanCurrencSettings.sortbynumdown)
		else
	--		PlaySound("igMainMenuOptionCheckBoxOff")
			TitanCurrencSettings.Sortbynothing = true
		end
		end)    
		local btnSortbynoneText = btnSortbynone:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnSortbynoneText:SetPoint("LEFT", btnSortbynone, "RIGHT", 0, 1)
	btnSortbynoneText:SetText("Do not sort currencies")
	Sortbynone:SetChecked(Sortbynothing)
	
	--Sort by Alpha Ascending
	
	local btnSortbyalphaup = CreateFrame("CheckButton", "SortbyAlphaAscending", TitanCurrencyPanel, "OptionsBaseCheckButtonTemplate")
	btnSortbyalphaup:SetPoint("TOPLEFT", 16, -95)
	btnSortbyalphaup:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
	--		PlaySound("igMainMenuOptionCheckBoxOn")
			TitanCurrencSettings.Sortbynothing = false
			TitanCurrencSettings.Sortbyalphaup = true
			TitanCurrencSettings.Sortbyalphadown = false
			TitanCurrencSettings.Sortbynumup = false
			TitanCurrencSettings.sortbynumdown = false
		Sortbynone:SetChecked(TitanCurrencSettings.Sortbynothing)
		SortbyAlphaAscending:SetChecked(TitanCurrencSettings.Sortbyalphaup)
		SortbyAlphaDescending:SetChecked(TitanCurrencSettings.Sortbyalphadown)
		SortbyNumAscending:SetChecked(TitanCurrencSettings.Sortbynumup)
		SortbyNumDescending:SetChecked(TitanCurrencSettings.sortbynumdown)
		else
	--		PlaySound("igMainMenuOptionCheckBoxOff")
			TitanCurrencSettings.Sortbyalphaup = false
			TitanCurrencSettings.Sortbynothing = true
			Sortbynone:SetChecked(TitanCurrencSettings.Sortbynothing)
		end
		end)  
		local btnSortbyalphaupText = btnSortbyalphaup:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnSortbyalphaupText:SetPoint("LEFT", btnSortbyalphaup, "RIGHT", 0, 1)
	btnSortbyalphaupText:SetText("Sort Currency type ascending")
	SortbyAlphaAscending:SetChecked(Sortbyalphaup)
	
	--Sort by Alpha Descending
	
    local btnSortbyalphadown = CreateFrame("CheckButton", "SortbyAlphaDescending", TitanCurrencyPanel, "OptionsBaseCheckButtonTemplate")
	btnSortbyalphadown:SetPoint("TOPLEFT", 16, -115)
	btnSortbyalphadown:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
	--		PlaySound("igMainMenuOptionCheckBoxOn")
			TitanCurrencSettings.Sortbynothing = false
			TitanCurrencSettings.Sortbyalphaup = false
			TitanCurrencSettings.Sortbyalphadown = true
			TitanCurrencSettings.Sortbynumup = false
			TitanCurrencSettings.sortbynumdown = false
		Sortbynone:SetChecked(TitanCurrencSettings.Sortbynothing)
		SortbyAlphaAscending:SetChecked(TitanCurrencSettings.Sortbyalphaup)
		SortbyAlphaDescending:SetChecked(TitanCurrencSettings.Sortbyalphadown)
		SortbyNumAscending:SetChecked(TitanCurrencSettings.Sortbynumup)
		SortbyNumDescending:SetChecked(TitanCurrencSettings.sortbynumdown)
		else
	--		PlaySound("igMainMenuOptionCheckBoxOff")
			TitanCurrencSettings.Sortbyalphadown = false
			TitanCurrencSettings.Sortbynothing = true
			Sortbynone:SetChecked(TitanCurrencSettings.Sortbynothing)
		end
		end)  
		local btnSortbyalphadownText = btnSortbyalphaup:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnSortbyalphadownText:SetPoint("LEFT", btnSortbyalphadown, "RIGHT", 0, 1)
	btnSortbyalphadownText:SetText("Sort Currency type descending")
	SortbyAlphaDescending:SetChecked(Sortbyalphadown)
	
	--Sort by numeric Ascending

	local btnSortbynumup = CreateFrame("CheckButton", "SortbyNumAscending", TitanCurrencyPanel, "OptionsBaseCheckButtonTemplate")
	btnSortbynumup:SetPoint("TOPLEFT", 16, -135)
	btnSortbynumup:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
	--		PlaySound("igMainMenuOptionCheckBoxOn")
			TitanCurrencSettings.Sortbynothing = false
			TitanCurrencSettings.Sortbyalphaup = false
			TitanCurrencSettings.Sortbyalphadown = false
			TitanCurrencSettings.Sortbynumup = true
			TitanCurrencSettings.sortbynumdown = false
		Sortbynone:SetChecked(TitanCurrencSettings.Sortbynothing)
		SortbyAlphaAscending:SetChecked(TitanCurrencSettings.Sortbyalphaup)
		SortbyAlphaDescending:SetChecked(TitanCurrencSettings.Sortbyalphadown)
		SortbyNumAscending:SetChecked(TitanCurrencSettings.Sortbynumup)
		SortbyNumDescending:SetChecked(TitanCurrencSettings.sortbynumdown)
		else
	--		PlaySound("igMainMenuOptionCheckBoxOff")
			TitanCurrencSettings.Sortbynumup = false
			TitanCurrencSettings.Sortbynothing = true
			Sortbynone:SetChecked(TitanCurrencSettings.Sortbynothing)
		end
		end)  
		local btnSortbynumupText = btnSortbynumup:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnSortbynumupText:SetPoint("LEFT", btnSortbynumup, "RIGHT", 0, 1)
	btnSortbynumupText:SetText("Sort Currency ammount ascending")
	SortbyNumAscending:SetChecked(Sortbynumup)
	
	--Sort by numeric Descending

	local btnSortbynumdown = CreateFrame("CheckButton", "SortbyNumDescending", TitanCurrencyPanel, "OptionsBaseCheckButtonTemplate")
	btnSortbynumdown:SetPoint("TOPLEFT", 16, -155)
	btnSortbynumdown:SetScript("OnClick", function(frame)
		if frame:GetChecked() then
	--		PlaySound("igMainMenuOptionCheckBoxOn")
			TitanCurrencSettings.Sortbynothing = false
			TitanCurrencSettings.Sortbyalphaup = false
			TitanCurrencSettings.Sortbyalphadown = false
			TitanCurrencSettings.Sortbynumup = false
			TitanCurrencSettings.sortbynumdown = true
		Sortbynone:SetChecked(TitanCurrencSettings.Sortbynothing)
		SortbyAlphaAscending:SetChecked(TitanCurrencSettings.Sortbyalphaup)
		SortbyAlphaDescending:SetChecked(TitanCurrencSettings.Sortbyalphadown)
		SortbyNumAscending:SetChecked(TitanCurrencSettings.Sortbynumup)
		SortbyNumDescending:SetChecked(TitanCurrencSettings.sortbynumdown)
		else
	--		PlaySound("igMainMenuOptionCheckBoxOff")
			TitanCurrencSettings.Sortbynothing = true
			TitanCurrencSettings.sortbynumdown = false
			Sortbynone:SetChecked(TitanCurrencSettings.Sortbynothing)
		end
		end)  
		local btnSortbynumdownText = btnSortbynumdown:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	btnSortbynumdownText:SetPoint("LEFT", btnSortbynumdown, "RIGHT", 0, 1)
	btnSortbynumdownText:SetText("Sort Currency ammount descending")
	SortbyNumDescending:SetChecked(Sortbynumdown)
		Sortbynone:SetChecked(TitanCurrencSettings.Sortbynothing)
		SortbyAlphaAscending:SetChecked(TitanCurrencSettings.Sortbyalphaup)
		SortbyAlphaDescending:SetChecked(TitanCurrencSettings.Sortbyalphadown)
		SortbyNumAscending:SetChecked(TitanCurrencSettings.Sortbynumup)
		SortbyNumDescending:SetChecked(TitanCurrencSettings.sortbynumdown)

     CURRENCY_INITIALIZED = true;
     MoneyFrame_Update("TitanPanelCurrencyButton", TitanPanelCurrencyButton_FindGold());
end

function TitanPanelCurrency_BreakMoney(money)
     -- Non-negative money only
     if (money >= 0) then
          local gold = floor(money / (COPPER_PER_SILVER * SILVER_PER_GOLD));
          local silver = floor((money - (gold * COPPER_PER_SILVER * SILVER_PER_GOLD)) / COPPER_PER_SILVER);
          local copper = mod(money, COPPER_PER_SILVER);
          return gold, silver, copper;
     end
end     

